% ----------------------------------------------------------------
%   DDSFTIME.M   DDS figure time plot file.
%   File plots the DDS signal(s) in the time domain.
%   
%   Input:	Time domain signal row vectors:
%		  rSigp .. phase
%		  rSigd .. dithered phase
%		  rSigt	.. truncated (and dithered) phase
%		  rSigs .. non-quantized sin amplitude
%		  rSigq .. quantized amplitude
%
%		What signal to write flags (1 plot, 0 do not plot)
%		  gTPhase  .. phase accumulator value
%		  gTDither .. dithered phase accumulator value
%		  gTTrunc  .. truncated (and dithered) phase
%			      accumulator value
%		  gTAmplitude .. non-quantized sin amplitude
%		  gTQuant  .. quantized sin amplitude
%
%		  gData  .. print the data in the plot
%		  gInPlot .. where to plot data in the
%			     plot - in the figure itself
%			     of by the figure
%		  iIndBase .. index base (defalut 1, change
%			      to 0 if desired). Set in ddsini.m
%
%   Output:	Plots, each in separate figure
%   Calls:	ddsgset.m .. only if in GUI
%		ddstext.m
%
%   Author: Martin Pechanec, Febraury 14, 1998
%           pechanec@iname.com
% ----------------------------------------------------------------

% -- Get all the parameters from the active control
% only if run from the shell
if 1 == gShell,
  ddsgset;
end

% Get the text strings
ddstext;

% -- Check all the plot flags
rcTFlags = [ gTPhase gTDither gTTrunc gTAmplitude gTQuant ];
rcTSignals = { rSigp, rSigd, rSigt, rSigs, rSigq };
ccLabels = { 'Full phase';
             'Dithered non-truncated phase';
             'Truncated phase';
             'Signal non-quantized amplitude samples';
             'Quantized signal amplitude samples' };

for iSignalInd = 1:length( rcTFlags )
  if 1 == rcTFlags( iSignalInd )

%   -- Stem the time signal
%   Prepare indices first

    iXmin = max( [iIndBase iSampleStart] );
    iXmax = min( [length( rcTSignals{ iSignalInd } )-1+iIndBase iSampleEnd] );

%   Check the indices .. if crossed, terminate here
    if iXmin > iXmax
      break;
    end

%   Create a new figure
    figure;

%   -- Prepare axes
    if 1 == gData & 0 == gInPlot,
      iHandleAxesTextTime = axes( 'Position', [0 0 1 1], 'Visible', 'off' );
      axes( 'Position', [ .1  .1  .7  .8 ] );
    end

%  -- Stem the data
   stem( ( iXmin:iXmax ), ...
         rcTSignals{ iSignalInd }( iXmin+1-iIndBase:iXmax+1-iIndBase ), 'x' );

%   -- Add title and labels
    title( ccLabels{ iSignalInd } );
    xlabel( 'Sample' );
    ylabel( 'Magnitude' );
    grid on;
    rAxis = axis;
    axis( [ iXmin-1 iXmax+1 rAxis(3:4) ] );

%   -- Add the text data
    if 1 == gData
      if 1 == gInPlot
        rAxis = axis;
        iHadleText = text( 0.8*rAxis(2), rAxis(4), rsText, ...
                        'HorizontalAlignment', 'left', ...
                        'VerticalAlignment', 'top' );
      else
        set( gcf, 'currentaxes', iHandleAxesTextTime );
        text( .82, .62, rsText, 'FontSize', 10 );
      end
    end
  end
end
