% -----------------------------------------------------------------------
% Direct Digital Synthesis simulator Graphic User Interface.
% Small version, primarily for displays 640x480 and 800x600.
% Controls are tighter together, same functions as in ddsg.m.
%
% Main simulator file. Run the simulator by typing
%
%   ddsgsm
%
% at the MATLAB prompt. The ddsg.m file and its associated ddsg.mat
% file must be on your path.
%
%   Author: Martin Pechanec, Febraury 14, 1997
%           pechanec@iname.com
%
%   Versions:
%     April 24, 1998:     First release
%
% -----------------------------------------------------------------------

% -- Set format to compact
format compact;

% -- Load the ddsgsm.mat file
load ddsgsm

% -- Set the shell variable .. we are in the GUI
gShell = 1;

% -- Set the GUI controlling variables .. needed to be
% changed if the figure size clips off some of the
% GUI

% -- Center the GUI on the screen
if ( 1 ~= exist( 'gCenter' ) )
  gCenter = 1;
end

% -- Resize the GUI figure
if ( 1 ~= exist( 'gResize' ) )
  gResize = 0;    % Resize the GUI figure. 0 .. no, 1 .. yes
                  % Default should be no (0). If there are problems
                  % with the size, set this to yes (1), resize the
                  % main GUI window to the comfortable size,
                  % from the MATLAB command line type
                  % get( gcf, 'Position' )
                  % which returns vector
                  % [iLeft iBottom iWidth iHeight]
                  % set the values to the the variables
                  % bellow in this file and set the gResize
                  % back to 0.
end

% Check the resize flag
if ( 0 ~= gResize )
  sResize = 'on';
else
  sResize = 'off';
end

% -- Position the GUI window
% Make sure the root screen units are pixels
set( 0, 'Units', 'pixels' );
if 0 ~= gCenter

% -- Center the GUI on the screen .. [left bottom width height]
% The GUI window width is 340 and height is 410
  rScreenSize = get( 0, 'ScreenSize' );

% Make the screen footer width to be iFooter pixels and the
% distance of the figure top from the screen top should
% be at least iHeaderMin pixels. The same for the left
% edges iLeftMin pixels.

  iGuiWidth = 340;
  iGuiHeight = 410;
  iHeaderMin = 20;
  iFooter = 35;
  iLeftMin = 20;

  rDdsGuiPosition = [ ( rScreenSize(3)-iGuiWidth )/2, ...
                      ( rScreenSize(4)+iFooter-iGuiHeight)/2, ...
                      iGuiWidth, ...
                      iGuiHeight ];

  if rDdsGuiPosition(2)+iGuiHeight > rScreenSize(4)-iHeaderMin
    rDdsGuiPosition(2) = rScreenSize(4) - iHeaderMin - iGuiHeight;
  end

  if rDdsGuiPosition(1) < iLeftMin
    rDdsGuiPosition(1) = iLeftMin;
  end
  clear iFooter iGuiWidth iGuiHeight iLeftMin

else

% -- GUI figure position on the screen in pixels.
  if 1 ~= exist( 'iDdsSmWidth' )
    iWidthSm = 340;   % GUI figure width in pixels
  end

  if 1 ~= exist( 'iDdsSmHeight' )
    iHeightSm = 410;  % GUI figure height in pixels
  end

  if 1 ~= exist( 'iDdsSmLeft' )
    iLeftSm = 100;    % Distance of the left figure edge
                    % from the monitor (screen) left edge.
  end

  if 1 ~= exist( 'iDdsSmBottom' )
    iBottomSm = 40;  % Distance of the figure bottom edge
                    % from the monitor (screen) bottom edge.
  end

% Set the position vector
  rDdsGuiPosition = [ iDdsSmLeft, iDdsSmBottom, iDdsSmWidth, iDdsSmHeight ];
end

% ---- Create the GUI objects
a = figure('Color',[0.8 0.8 0.8], ...
        'Colormap',mat0, ...
        'Name','DDS Simulator', ...
        'PointerShapeCData',mat1, ...
        'Position',rDdsGuiPosition, ...
        'RendererMode','manual', ...
        'Resize',sResize, ...
        'Tag','Figure_eDds');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[3.75 144 248.25 39], ...
        'Style','frame', ...
        'Tag','Frame1');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[4.5 265.5 247.5 38.25], ...
        'Style','frame', ...
        'Tag','Frame1');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[3.75 225 248.25 38.25], ...
        'Style','frame', ...
        'Tag','Frame1');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[3.75 185.25 248.25 37.5], ...
        'Style','frame', ...
        'Tag','Frame1');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[3.75 3.75 248.25 45], ...
        'Style','frame', ...
        'Tag','Frame3');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[3.75 55.5 78 85.5], ...
        'Style','frame', ...
        'Tag','Frame2');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','clear rSigp rSigd rSigt rSigs', ...
        'Position',[9.75 60.75 64.5 17.25], ...
        'String','Clear signals', ...
        'Tag','Btn_Clear');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[9.75 246.75 84 11.25], ...
        'String','Bits to phase table p=', ...
        'Style','text', ...
        'Tag','Text_iP');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[13.5 270 79.5 13.5], ...
        'String','Accumulator width n=', ...
        'Style','text', ...
        'Tag','Text_iN');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[94.5 269.25 45 15], ...
        'String','11', ...
        'Style','edit', ...
        'Tag','Edit_iN');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[95.25 244.5 45 15], ...
        'String','5', ...
        'Style','edit', ...
        'Tag','Edit_iP');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTrunc = iValue;', ...
        'Position',[147 242.25 93 17.25], ...
        'String','Phase truncation', ...
        'Style','checkbox', ...
        'Tag','Check_gTrunc', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gQuant = iValue;', ...
        'Position',[148.5 203.25 96 17.25], ...
        'String','Amplitude quantization', ...
        'Style','checkbox', ...
        'Tag','Check_gQuant');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gDit = iValue;', ...
        'Position',[149.25 161.25 95.25 18], ...
        'String','Phase dithering', ...
        'Style','checkbox', ...
        'Tag','Check_gDit');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[10.5 205.5 81.75 13.5], ...
        'String','Amplitude bits b=', ...
        'Style','text', ...
        'Tag','Text_iB');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[95.25 204.75 45 15], ...
        'String','6', ...
        'Style','edit', ...
        'Tag','Edit_iB');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[14.25 284.25 78 15], ...
        'String','Tuning number F=', ...
        'Style','text', ...
        'Tag','Text_iF');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[94.5 285 45 15], ...
        'String','32', ...
        'Style','edit', ...
        'Tag','Edit_iF');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gStem = iValue;', ...
        'Position',[87 72.75 47.25 15], ...
        'String','Stem', ...
        'Style','checkbox', ...
        'Tag','Check_gStem');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gAugment = iValue;', ...
        'Position',[87 57 47.25 15], ...
        'String','Augment', ...
        'Style','checkbox', ...
        'Tag','Check_gAugment', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','ddsgt;', ...
        'Position',[86.25 116.25 162.75 24], ...
        'String','Simulate', ...
        'Tag','Btn_Simulate');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gClear = iValue;', ...
        'Position',[12 79.5 55.5 15.75], ...
        'String','Clear in run', ...
        'Style','checkbox', ...
        'Tag','Check_gClear');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[144.75 283.5 62.25 15.75], ...
        'String','Driving f [Hz] fv=', ...
        'Style','text', ...
        'Tag','Text_Fv');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[208.5 285.75 39 14.25], ...
        'String','1', ...
        'Style','edit', ...
        'Tag','Edit_Fv', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[9 162.75 84 15], ...
        'String','Polynomial degree dp=', ...
        'Style','text', ...
        'Tag','Text_iDitPoly');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[95.25 164.25 45 15], ...
        'String','10', ...
        'Style','edit', ...
        'Tag','Edit_iDitPoly');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[10.5 147 81.75 15], ...
        'String','Dithered bits db=', ...
        'Style','text', ...
        'Tag','Text_iDitBits');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[95.25 147.75 45 15], ...
        'String','7', ...
        'Style','edit', ...
        'Tag','Edit_iDitBits');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[12 189.75 81 13.5], ...
        'String','Amplitude offset aoff=', ...
        'Style','text', ...
        'Tag','Text_Aoff');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[95.25 189 45 15], ...
        'String','0.7', ...
        'Style','edit', ...
        'Tag','Edit_Aoff');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[7.5 229.5 87 13.5], ...
        'String','Phase delta offset poff=', ...
        'Style','text', ...
        'Tag','Text_Poff');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[95.25 228.75 45 15], ...
        'String','0.5', ...
        'Style','edit', ...
        'Tag','Edit_Poff');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','ddsfplot;', ...
        'Position',[174.75 58.5 73.5 27.75], ...
        'String','Plot spectrum', ...
        'Tag','Btn_Plot');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','ddsgset;', ...
        'Position',[9 98.25 66 18], ...
        'String','Set parameters', ...
        'Tag','Btn_SetParameters');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','ddsgini;', ...
        'Position',[9 118.5 66 18], ...
        'String','Initialize', ...
        'Tag','Btn_Initialize');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','left', ...
        'Position',[86.25 91.5 162 22.5], ...
        'String','> Idle (L=64s)', ...
        'Style','text', ...
        'Tag','Text_Message');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gData = iValue;', ...
        'Position',[136.5 72.75 37.5 15], ...
        'String','Data', ...
        'Style','checkbox', ...
        'Tag','Check_gData', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gInPlot = iValue;', ...
        'Position',[135.75 56.25 37.5 15.75], ...
        'String','In plot', ...
        'Style','checkbox', ...
        'Tag','Check_gInPlot', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','ddsftime', ...
        'Position',[166.5 22.5 81.75 22.5], ...
        'String','Time plots', ...
        'Tag','Btn_TimePlots');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[71.25 30.75 45 15], ...
        'String','1', ...
        'Style','edit', ...
        'Tag','Edit_iSampleStart');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','left', ...
        'Position',[9.75 28.5 59.25 15], ...
        'String','Starting sample:', ...
        'Style','text', ...
        'Tag','Text_iSampleStart');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','left', ...
        'Position',[10.5 14.25 59.25 15], ...
        'String','Ending sample:', ...
        'Style','text', ...
        'Tag','Text_iSampleEnd');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTPhase = iValue;', ...
        'Position',[119.25 31.5 39.75 15], ...
        'String','Phase', ...
        'Style','checkbox', ...
        'Tag','Check_gTPhase', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTDither = iValue;', ...
        'Position',[119.25 19.5 36 12], ...
        'String','Dith', ...
        'Style','checkbox', ...
        'Tag','Check_gTDither');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTTrunc = iValue;', ...
        'Position',[119.25 5.25 50.25 15], ...
        'String','Trunc', ...
        'Style','checkbox', ...
        'Tag','Check_gTTrunc');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTAmplitude = iValue;', ...
        'Position',[212.25 5.25 32.25 15], ...
        'String','Ampl', ...
        'Style','checkbox', ...
        'Tag','Check_gTAmplitude');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTQuant = iValue;', ...
        'Position',[166.5 5.25 36.75 15], ...
        'String','Quant', ...
        'Style','checkbox', ...
        'Tag','Check_gTQuant');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[71.25 14.25 45 15], ...
        'String','100', ...
        'Style','edit', ...
        'Tag','Edit_iSampleEnd');

% ---- GUI objects created ----
