function roY = ddsph( iiN, iiF, iiPer )
%DDS phase number signal generation
%   Y = DDSPH(N,F) generates integer phase sequence values
%       ranging from 0 to 2^N-1. The F is a phase increment
%       per one sample. The length of the row vector Y is
%       2^N.
%
%   Y = DDSPH(N,F,P) same as above, but P specifies number of periods
%       which going to be generated. The length of the row vector Y is
%       P*(2^N)/GCD(2^N,F).

%   Author: Martin Pechanec, October 22, 1997
%           pechanec@iname.com

% -- Check the input argument sizes
[iR,iC] = size( iiN );
if ( iC ~= 1 | iR ~= 1 ),
  error( 'DDSP: Input N cannot be a vector, integer is expected.' );
end;

[iR,iC] = size( iiF );
if ( iC ~= 1 | iR ~= 1 ),
  error( 'DDSP: Input F cannot be a vector, integer is expected.' );
end;

% Set the generated sequence length
if ( nargin == 3 ),
  if ( iC ~= 1 | iR ~= 1 ),
    error( 'DDSP: Input P cannot be a vector, integer is expected.' );
  end;
  iLen = iiPer*(2^iiN)/gcd( 2^iiN, iiF );  
else
  iLen = 2^iiN;
end

% -- Generate the sequence, set initial phase to zero

roY = zeros( 1, iLen );
iPhase = 0;
iModulus = 2^iiN;
for iInd = 1:iLen,
  roY(iInd) = iPhase;
  iPhase = mod( iPhase + iiF, iModulus );
end
