function ioHandle = ddsplota( ziFv, riY, siFormat )
%DDS augmented plot. The function must get as input the periodic spectrum.
%It augments the spectrum vector by its first component to get component at the
%sampling frequency for convenient plotting.
%
%   H = DDSPLOTA(Y) plots the spectral lines of the psd using F=1Hz as a driving
%       frequency of the DDS
%   H = DDSPLOTA(F,Y) plots the spectral lines of the psd using F as a driving
%       frequency of the DDS
%   H = DDSPLOTA(F,Y,S) does the same as above, but using the format string.
%       Only the line colors and types are permitted!
%
%       F .. driving frequency
%       Y .. psd vector
%       S .. format string
%
%       H .. output figure handle

%   Author: Martin Pechanec, October 22, 1997
%           pechanec@iname.com
%   z at ziFv means mutant (either vector or float for example)

% -- Check the number of input arguments
if ( nargin == 1 )
  riY = ziFv;
  Freq = 1;  
end

% -- Make the signal vector row
[iR,iC] = size( riY );
if iC == 1,
  riY = riY.';   % Make it a row
end

if ( nargin ~= 3 )
  siFormat = 'b-';
end

if ( nargin >= 2 )
  Freq = ziFv;
end

% Calculate the frequency vector augmented by one
iN = length( riY );
rFreq = (Freq * (1/iN)).*[0:iN];

% -- Plot the augment the signal vector by the first element .. periodic spectrum
iHandle = plot( rFreq, [ riY riY(1) ], siFormat );
rAxis = axis;
axis( [ 0 rFreq(iN) rAxis(3:4) ] );
grid on;
zoom;

if ( nargout > 0 )
  ioHandle = iHandle;
end
