function ioHandle = ddsplotf( ziFv, riY, siFormat )
%DDS frequency plot. It plots the spectrum with respect
%to the sampling frequency. The input must be the whole periodic
%spectrum.
%
%   H = DDSPLOTF(Y) plots the spectral lines of the psd using F=1Hz as a driving
%       frequency of the DDS
%   H = DDSPLOTF(F,Y) plots the spectral lines of the psd using F as a driving
%       frequency of the DDS
%   H = DDSPLOTF(F,Y,S) does the same as above, but using the format string.
%       Only the line colors and types are permitted!
%
%       F .. driving frequency
%       Y .. psd vector
%       S .. format string
%
%       H .. output figure handle

%   Author: Martin Pechanec, October 22, 1997
%           pechanec@iname.com
%   z at ziFv means mutant (either vector or float for example)

% -- Check the number of input arguments
if ( nargin == 1 )
  riY = ziFv;
  Freq = 1;
end

% -- Make the signal vector row
[iR,iC] = size( riY );
if iC == 1,
  riY = riY.';   % Make it a row
end

if ( nargin ~= 3 )
  siFormat = 'b-';
end

if ( nargin >= 2 )
  Freq = ziFv;
end

% Calculate the frequency vector
iN = length( riY );
rFreq = (Freq * (1/iN)).*[0:iN-1];

% -- Plot the signal
iHandle = plot( rFreq, riY, siFormat );
rAxis = axis;
axis( [ 0 rFreq(iN-1) rAxis(3:4) ] );
grid on;
zoom;

if ( nargout > 0 )
  ioHandle = iHandle;
end
