function roAmp = ddssin( iiP, riPhase, fiDeltaPhiFrac )
%DDS phase number signal generation
%   Y = DDSSIN(P,X) calculates the sin(2*pi*X/(2^P)+fDeltaPhi)
%       where fDeltaPhi = fPhiStep/2 = 2*pi/(2^P)/2. 
%         P .. # bits used to feed the phase->sin table
%         X .. input row integer phase vector; values from
%              0 to 2^P-1
%
%   Y = DDSSIN(P,X,D) same as above, but the phase difference
%         is fDeltaPhi = D*fPhiStep.
%         D .. phase step fraction phase offset

%   Author: Martin Pechanec, October 22, 1997
%           pechanec@iname.com

% -- Check the input argument sizes
[iR,iC] = size( iiP );
if ( iC ~= 1 | iR ~= 1 ),
  error( 'DDSP: Input P cannot be a vector, integer is expected.' );
end;

% Set the phase step
PhiStep = (2*pi)/(2^iiP);

% Set the phase offset
if ( nargin >= 2 ),
  [iR,iC] = size( fiDeltaPhiFrac );
  if ( iC ~= 1 | iR ~= 1 ),
    error( 'DDSP: Input D cannot be a vector, real is expected.' );
  end
  DeltaPhi = fiDeltaPhiFrac * PhiStep;
else
  DeltaPhi = PhiStep / 2;
end

% Because of some wierd behaviour if fiDeltaPhiFrac == 0
% it should be slightly off.

EpsDeltaPhi = 1e-14;
if abs( DeltaPhi ) < EpsDeltaPhi,
  DeltaPhi = EpsDeltaPhi;
end

% -- Generate the sequence, set initial phase to zero
roAmp = sin( PhiStep .* riPhase + DeltaPhi );
