function ioHandle = ddsstem( riX, riY, siFormat )
%DDS modified stem plot
%
%   H = DDSSTEM(Y) plots the spectral lines of the psd
%   H = DDSSTEM(X,Y) does the same but according to the frequency
%       vector X
%   H = DDSSTEM(X,Y,S) does the same as above, but using the format string.
%       Only the line colors and types are permitted!
%
%       X .. frequency vector
%       Y .. psd vector
%       S .. format string
%
%       H .. output figure handle

%   Author: Martin Pechanec, October 22, 1997
%           pechanec@iname.com

% -- Check the number of input arguments
switch nargin
  case 1
    iN = length( riX );
    riY = riX;
    rFreq = [0:iN-1];
    siFormat = 'b-';

  case 2
    rFreq = iX;
    siFormat = 'b-';

  case 3
    rFreq = iX;

  otherwise
    error( 'DDSSTEM: Wrong number of input parameters. It can be 1, 2, or 3 only!' );
end

% -- Stem the signal
% Calculate the cX and cY vectors
iN = length( riY );

Min = min( riY );
cX = NaN .* ones( 3*iN, 1 );
cY = cX;

cX( 1:3:3*iN ) = rFreq;
cX( 2:3:3*iN ) = rFreq;

cY( 1:3:3*iN ) = Min;

% -- Remove zero lenght spectral points
rEraseInd = find( riY <= Min+eps );
riY( rEraseInd ) = NaN;
cY( 2:3:3*iN ) = riY;
cY( (rEraseInd-1)*3+1 ) = NaN;

% -- Stem the values
iHandle = plot( cX, cY, siFormat );
rAxis = axis;
axis( [ 0 rFreq(iN-1) rAxis(3:4) ] );
grid on;
zoom;

if ( nargout > 0 )
  ioHandle = iHandle;
end
