function ioHandle = ddsstemf( ziFv, riY, siFormat )
%DDS frequency modified stem plot. It stems the spectrum with respect
%to the sampling frequency. The input must be the whole periodic
%spectrum.
%
%   H = DDSSTEMF(Y) plots the spectral lines of the psd using F=1Hz as a driving
%       frequency of the DDS
%   H = DDSSTEMF(F,Y) plots the spectral lines of the psd using F as a driving
%       frequency of the DDS
%   H = DDSSTEMF(F,Y,S) does the same as above, but using the format string.
%       Only the line colors and types are permitted!
%
%       F .. driving frequency
%       Y .. psd vector
%       S .. format string
%
%       H .. output figure handle

%   Author: Martin Pechanec, October 22, 1997
%           pechanec@iname.com
%   z at ziFv means mutant (either vector or float for example)

% -- Set the [dB] epsilon
EpsdB = 0.01;

% -- Check the number of input arguments
if ( nargin == 1 )
  riY = ziFv;
  Freq = 1;  
end

% -- Make the signal vector row
[iR,iC] = size( riY );
if iC == 1,
  riY = riY.';   % Make it a row
end

if ( nargin ~= 3 )
  siFormat = 'b-';
end

if ( nargin >= 2 )
  Freq = ziFv;
end

% Calculate the frequency vector
iN = length( riY );
rFreq = (Freq * (1/iN)).*[0:iN-1];

% -- Stem the signal
% Calculate the cX and cY vectors
iN = length( riY );

Min = min( riY );
cX = NaN .* ones( 3*iN, 1 );
cY = cX;

cX( 1:3:3*iN ) = rFreq;
cX( 2:3:3*iN ) = rFreq;

cY( 1:3:3*iN ) = Min;

% -- Remove zero lenght spectral points
if Min < 0
  rEraseInd = find( riY <= Min+EpsdB ); 
else
  rEraseInd = find( riY <= Min+eps );
end
riY( rEraseInd ) = NaN;
cY( 2:3:3*iN ) = riY;
cY( (rEraseInd-1)*3+1 ) = NaN;

% -- Stem the values
iHandle = plot( cX, cY, siFormat );
rAxis = axis;
axis( [ 0 rFreq(iN-1) rAxis(3:4) ] );
grid on;
zoom;

if ( nargout > 0 )
  ioHandle = iHandle;
end
